package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````L"D```````!``````````%C!````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````,@:````````R!H`````````
M$`````````$````%`````"``````````(``````````@````````?4``````
M``!]0``````````0`````````0````0`````<`````````!P`````````'``
M```````X1@```````#A&`````````!`````````!````!@```+"[````````
ML,L```````"PRP```````'`$````````&!4`````````$`````````(````&
M````P+L```````#`RP```````,#+````````$`(````````0`@````````@`
M````````!`````0````X`P```````#@#````````.`,````````@````````
M`"``````````"``````````$````!````%@#````````6`,```````!8`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````(``````````@``````````@`````````4.5T9`0`
M``!0KP```````%"O````````4*\```````#T`````````/0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````L+L```````"PRP```````+#+````
M````4`0```````!0!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````$`````4```!'3E4``@``P`0````#````````
M``0````4`````P```$=.50`CH1A)E]?V8'QCRTLZ/FQQX.<TY`0````0````
M`0```$=.50```````P````(``````````````!$```!#````!`````@````@
M'!``!4`$AB@"0`"0A@"`@@D`($D@!`BXHA%%N@`""@````!#````1@```$D`
M``!*````4````%$```!3````5P```%@`````````6@```%T```!?````8```
M````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP,+E/RRZXY)\^Z%L8&L)0]9FK\QFQ;F<0#CRBQS$B0600D75[(D'<-,-
M%.*>,F+;[=O-XYX,.I<+5J2;EJ?=HVM^J9R;T67.;>&G`@H*BA!7H^#[20``
M`````````````````````````````/<!```2````````````````````````
M``P!```2`````````````````````````),````2````````````````````
M`````)8"```2`````````````````````````,P!```2````````````````
M`````````),!```2`````````````````````````%$"```2````````````
M`````````````($"```2`````````````````````````"(!```2````````
M`````````````````!$````@`````````````````````````!4"```2````
M`````````````````````$4#```2`````````````````````````-H!```2
M`````````````````````````!H"```2`````````````````````````*H!
M```2`````````````````````````"D#```2````````````````````````
M`%,!```2`````````````````````````+0````2````````````````````
M`````$,!```2`````````````````````````#P"```2````````````````
M`````````'L"```2`````````````````````````#4!```2````````````
M`````````````-@"```2`````````````````````````%@"```2````````
M`````````````````-T#```2`````````````````````````"`````@````
M`````````````````````+$!```2`````````````````````````!$!```2
M`````````````````````````&T"```2`````````````````````````#P`
M```@`````````````````````````*\"```2````````````````````````
M`%8````2`````````````````````````(,!```2````````````````````
M`````',````2`````````````````````````/`````2````````````````
M`````````(0````2`````````````````````````-\!```2````````````
M`````````````'0"```2`````````````````````````-0````2````````
M`````````````````,\"```2`````````````````````````'4!```2````
M`````````````````````!,#```2`````````````````````````.4"```2
M`````````````````````````*0"```2`````````````````````````&<!
M```2`````````````````````````.8!```2````````````````````````
M`%\"```2`````````````````````````!8!```2````````````````````
M`````"L"```2`````````````````````````"(#```2````````````````
M`````````&8"```2`````````````````````````,@"```2````````````
M`````````````)\````2`````````````````````````+<"```2````````
M`````````````````)X!```2`````````````````````````-(!```2````
M`````````````````````"("```2``````````````````````````4#```2
M`````````````````````````!L#```2`````````````````````````$D"
M```2`````````````````````````%P!```2````````````````````````
M`&0````2`````````````````````````(\"```2````````````````````
M`````.P"```2`````````````````````````$,"```2````````````````
M`````````,(````2`````````````````````````.8#```2`!``8%\`````
M``!W`````````#<$```2`!``(%````````!8"P```````#8#```2`!``H"<`
M```````,`@```````%<#```2`!``<$D````````)`````````(4#```2`!``
M@%L```````#9`P```````%T$```2`!``@$D````````"`@```````"8$```0
M`!H`(-```````````````````&@#```2`!``D$L````````E`````````)L#
M```2`!``@$X```````!\`````````/(#```1`!(``'`````````$````````
M``X$```2`!```$@````````T`````````#($```0`!H`R.``````````````
M`````$L$```2`!``,$\```````#F``````````$$```0`!D``-``````````
M`````````+\#```2`!``P$L```````#<`````````#L#```1`!H`0-``````
M```(`````````,$"```1`!H`8-`````````(`````````#P#```A`!H`0-``
M```````(`````````$0$```0`!D`(-```````````````````&H$```1`!D`
M&-`````````(`````````'4#```2`!``4&`````````%``````````<$```2
M`!``L"D````````O`````````!8$```2`!``X%\```````!E``````````,$
M```@`!D``-````````````````````$!```1`!H`(-`````````$````````
M`#T#```A`!H`0-`````````(`````````,L#```2`!```$\````````A````
M`````/8"```B`````````````````````````*D#```2`!``D$@```````#8
M`````````.,````1`!H`@-`````````!`````````'0$```2`!``H$P`````
M``#6`0````````!L:6)P97)L+G-O+C4N,S``7U]G;6]N7W-T87)T7U\`7TE4
M35]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R
M:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R
M;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?
M=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`&QI8G!T:')E860N<V\N,`!C;&]S90!L<V5E:S8T`')E860`;W!E;C8T
M`%]?97)R;F]?;&]C871I;VX`<'1H<F5A9%]G971S<&5C:69I8P!L:6)C+G-O
M+C8`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL
M:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K
M`'-T<FQE;@!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S
M=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R
M<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER
M-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S
M<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T
M97)?871F;W)K`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB
M8U]C<W5?9FEN:0!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A
M;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N
M86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T9&EN7W5S960`
M7U]D871A7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S=5]I;FET`%]?8G-S7W-T
M87)T`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T
M:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R
M+C$T`$=,24)#7S(N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C(N-0!'3$E"0U\R
M+C,N-`````(```````,``@````0``P``````!``%``(`!``$``0`````````
M!``$`````P`$``0```````0`!`````0```````````````(`!`````0````$
M``0`!`````(`!`````8`!``$``0````$`````@`$``,`!``$```````'``0`
M!`````$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``0`!``$``$``0`!
M``$``0`!````!``!``0``0````$````!``4`"P(``!````!@````E)&6!@``
M!P"!!```$````!1I:0T```8`C`0``!````!R&6D)```%`)8$```0````=1II
M"0``!`"B!```$````'09:0D```,`K@0````````!``$`O`$``!``````````
M=1II"0```@"B!````````+#+````````"`````````"0*@```````+C+````
M````"`````````!0*@````````C0````````"``````````(T````````!C0
M````````"`````````#H<@```````,#/````````!@````D`````````````
M`,C/````````!@````H``````````````-#/````````!@```!``````````
M`````-C/````````!@```!H``````````````.#/````````!@```!X`````
M`````````.C/````````!@```%X``````````````/#/````````!@```"$`
M`````````````/C/````````!@```"(``````````````"#0````````!0``
M`%L``````````````$#0````````!0```%(``````````````&#0````````
M!0```%,``````````````(#0````````!0```&```````````````.C-````
M````!P````$``````````````/#-````````!P````(``````````````/C-
M````````!P````,```````````````#.````````!P````0`````````````
M``C.````````!P````4``````````````!#.````````!P````8`````````
M`````!C.````````!P````<``````````````"#.````````!P````@`````
M`````````"C.````````!P````L``````````````##.````````!P````P`
M`````````````#C.````````!P````T``````````````$#.````````!P``
M``X``````````````$C.````````!P````\``````````````%#.````````
M!P```!$``````````````%C.````````!P```!(``````````````&#.````
M````!P```!,``````````````&C.````````!P```!0``````````````'#.
M````````!P```!4``````````````'C.````````!P```!8`````````````
M`(#.````````!P```!<``````````````(C.````````!P```!@`````````
M`````)#.````````!P```!D``````````````)C.````````!P```!L`````
M`````````*#.````````!P```!P``````````````*C.````````!P```!T`
M`````````````+#.````````!P```!\``````````````+C.````````!P``
M`"```````````````,#.````````!P```",``````````````,C.````````
M!P```"0``````````````-#.````````!P```"4``````````````-C.````
M````!P```"8``````````````.#.````````!P```"<``````````````.C.
M````````!P```"@``````````````/#.````````!P```"D`````````````
M`/C.````````!P```"H```````````````#/````````!P```"L`````````
M``````C/````````!P```"P``````````````!#/````````!P```"T`````
M`````````!C/````````!P```"X``````````````"#/````````!P```"\`
M`````````````"C/````````!P```#```````````````##/````````!P``
M`#$``````````````#C/````````!P```#(``````````````$#/````````
M!P```#,``````````````$C/````````!P```#0``````````````%#/````
M````!P```#4``````````````%C/````````!P```#8``````````````&#/
M````````!P```#<``````````````&C/````````!P```#@`````````````
M`'#/````````!P```#D``````````````'C/````````!P```#H`````````
M`````(#/````````!P```#L``````````````(C/````````!P```#P`````
M`````````)#/````````!P```#T``````````````)C/````````!P```#X`
M`````````````*#/````````!P```#\``````````````*C/````````!P``
M`$```````````````+#/````````!P```$$``````````````+C/````````
M!P```$(`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!;FO``!(A<!T`O_02(/$",,``````/\ULJT``/+_);.M
M```/'P#S#Q[Z:`````#RZ>'___^0\P\>^F@!````\NG1____D/,/'OIH`@``
M`/+IP?___Y#S#Q[Z:`,```#RZ;'___^0\P\>^F@$````\NFA____D/,/'OIH
M!0```/+ID?___Y#S#Q[Z:`8```#RZ8'___^0\P\>^F@'````\NEQ____D/,/
M'OIH"````/+I8?___Y#S#Q[Z:`D```#RZ5'___^0\P\>^F@*````\NE!____
MD/,/'OIH"P```/+I,?___Y#S#Q[Z:`P```#RZ2'___^0\P\>^F@-````\ND1
M____D/,/'OIH#@```/+I`?___Y#S#Q[Z:`\```#RZ?'^__^0\P\>^F@0````
M\NGA_O__D/,/'OIH$0```/+IT?[__Y#S#Q[Z:!(```#RZ<'^__^0\P\>^F@3
M````\NFQ_O__D/,/'OIH%````/+IH?[__Y#S#Q[Z:!4```#RZ9'^__^0\P\>
M^F@6````\NF!_O__D/,/'OIH%P```/+I<?[__Y#S#Q[Z:!@```#RZ6'^__^0
M\P\>^F@9````\NE1_O__D/,/'OIH&@```/+I0?[__Y#S#Q[Z:!L```#RZ3'^
M__^0\P\>^F@<````\NDA_O__D/,/'OIH'0```/+I$?[__Y#S#Q[Z:!X```#R
MZ0'^__^0\P\>^F@?````\NGQ_?__D/,/'OIH(````/+IX?W__Y#S#Q[Z:"$`
M``#RZ=']__^0\P\>^F@B````\NG!_?__D/,/'OIH(P```/+IL?W__Y#S#Q[Z
M:"0```#RZ:']__^0\P\>^F@E````\NF1_?__D/,/'OIH)@```/+I@?W__Y#S
M#Q[Z:"<```#RZ7']__^0\P\>^F@H````\NEA_?__D/,/'OIH*0```/+I4?W_
M_Y#S#Q[Z:"H```#RZ4']__^0\P\>^F@K````\NDQ_?__D/,/'OIH+````/+I
M(?W__Y#S#Q[Z:"T```#RZ1']__^0\P\>^F@N````\ND!_?__D/,/'OIH+P``
M`/+I\?S__Y#S#Q[Z:#````#RZ>'\__^0\P\>^F@Q````\NG1_/__D/,/'OIH
M,@```/+IP?S__Y#S#Q[Z:#,```#RZ;'\__^0\P\>^F@T````\NFA_/__D/,/
M'OIH-0```/+ID?S__Y#S#Q[Z:#8```#RZ8'\__^0\P\>^F@W````\NEQ_/__
MD/,/'OIH.````/+I8?S__Y#S#Q[Z:#D```#RZ5'\__^0\P\>^F@Z````\NE!
M_/__D/,/'OKR_R7]JP``#Q]$``#S#Q[Z\O\E[:D```\?1```\P\>^O+_)>6I
M```/'T0``/,/'OKR_R7=J0``#Q]$``#S#Q[Z\O\EU:D```\?1```\P\>^O+_
M)<VI```/'T0``/,/'OKR_R7%J0``#Q]$``#S#Q[Z\O\EO:D```\?1```\P\>
M^O+_);6I```/'T0``/,/'OKR_R6MJ0``#Q]$``#S#Q[Z\O\EI:D```\?1```
M\P\>^O+_)9VI```/'T0``/,/'OKR_R65J0``#Q]$``#S#Q[Z\O\EC:D```\?
M1```\P\>^O+_)86I```/'T0``/,/'OKR_R5]J0``#Q]$``#S#Q[Z\O\E=:D`
M``\?1```\P\>^O+_)6VI```/'T0``/,/'OKR_R5EJ0``#Q]$``#S#Q[Z\O\E
M7:D```\?1```\P\>^O+_)56I```/'T0``/,/'OKR_R5-J0``#Q]$``#S#Q[Z
M\O\E1:D```\?1```\P\>^O+_)3VI```/'T0``/,/'OKR_R4UJ0``#Q]$``#S
M#Q[Z\O\E+:D```\?1```\P\>^O+_)26I```/'T0``/,/'OKR_R4=J0``#Q]$
M``#S#Q[Z\O\E%:D```\?1```\P\>^O+_)0VI```/'T0``/,/'OKR_R4%J0``
M#Q]$``#S#Q[Z\O\E_:@```\?1```\P\>^O+_)?6H```/'T0``/,/'OKR_R7M
MJ```#Q]$``#S#Q[Z\O\EY:@```\?1```\P\>^O+_)=VH```/'T0``/,/'OKR
M_R75J```#Q]$``#S#Q[Z\O\ES:@```\?1```\P\>^O+_)<6H```/'T0``/,/
M'OKR_R6]J```#Q]$``#S#Q[Z\O\EM:@```\?1```\P\>^O+_):VH```/'T0`
M`/,/'OKR_R6EJ```#Q]$``#S#Q[Z\O\EG:@```\?1```\P\>^O+_)96H```/
M'T0``/,/'OKR_R6-J```#Q]$``#S#Q[Z\O\EA:@```\?1```\P\>^O+_)7VH
M```/'T0``/,/'OKR_R5UJ```#Q]$``#S#Q[Z\O\E;:@```\?1```\P\>^O+_
M)66H```/'T0``/,/'OKR_R5=J```#Q]$``#S#Q[Z\O\E5:@```\?1```\P\>
M^O+_)4VH```/'T0``/,/'OKR_R5%J```#Q]$``#S#Q[Z\O\E/:@```\?1```
M\P\>^O+_)36H```/'T0``/,/'OKR_R4MJ```#Q]$``#S#Q[Z\O\E):@```\?
M1```\P\>^O+_)1VH```/'T0``/,/'OI!5%5(@^PXB7PD'$B-?"0<2(ET)!!(
MC70D$$B)5"0(2(U4)`AD2(L$)2@```!(B40D*#'`Z'/___](BS7<IP``2(L]
M#:@``$B)\NAM.```@#V&J````'4OZ$_]__](B06XN```2(G'2(7`#X2.`0``
MZ)?]__^+/0&H``#HS/O__\:`T0D```"+/>^G``#HNOO__XL]Y*<``("(.@0`
M``+HJ/O__X"(.@0```&+1"0<C7@%2&/_2,'G`^A^_O__3(M,)!"+5"0<QP4[
MN```!````$B)P4B)!2FX``!)BP%(B0%(C05(20``2(E!"$B+!8&G``!(B4$0
M2(T%-4D``$B)01B#^@%^+42-0OZ^`0```$F#P`(/'X0``````$F+!/&-?@1(
M@\8!2&/_2(E$^?A).?!UZ(U"!$4QP(/"`TB+/=BW``!(F$B--4\?``!(QT3!
M^`````#H0?O__T&)Q(7`=%-(BSVSMP``2(UL)"3H*?W__S'`2(GN2(T]@4<`
M`.A(&```2(7`=#U(BSV,MP``Z,?Z___H4OS__TB+1"0H9$@S!"4H````=4](
M@\0X1(G@74%<PTB+/6"W``#H6_O__T&)Q.N<2(L]1[<``$B%_W0'Z.4U``#K
ML$B-/=5&``!(B>[HY!<``$B)!26W``!(B<=(A<!TDNO9Z-[\__^_`0```.C$
M^O__#Q]``/,/'OHQ[4F)T5Y(B>)(@^3P4%1,C06&-@``2(T-#S8``$B-/<C]
M____%?*E``#TD$B-/3FF``!(C04RI@``2#GX=!5(BP7>I0``2(7`=`G_X`\?
M@`````###Q^``````$B-/0FF``!(C34"I@``2"G^2(GP2,'N/TC!^`-(`<9(
MT?YT%$B+!:6E``!(A<!T"/_@9@\?1```PP\?@`````#S#Q[Z@#TFI@```'4K
M54B#/8*E````2(GE=`Q(BSV6I0``Z&GY___H9/___\8%_J4```%=PP\?`,,/
M'X``````\P\>^NEW____#Q^``````$%73(U/.$%6055!5%532('LF`(``&1(
MBP0E*````$B)A"2(`@``,<!(B>),C90D@````$F)T&8N#Q^$``````!!BP%)
MBS%)@\`028/!"`_(B<!(B?%)B4#P2(GP2,'I($C!Z"A(P>XX)0#_``!("?!(
MB<Y(P>$(2,'F&('A``#_`(GV2`GP2`G(28E`^$TYT'6N2(VR``(```\?@```
M``!(BT)H2#-"0$B#P@A(,T((2#-"^$B-#`!(P>@?2`G(@^#_2(E">$@Y\G75
M3(L'3(M/$$B+7R!,BU<83(G`3(G"2(MT)`A,BW0D&$C!ZAM(P>`%2`G0`P0D
M28VL,IEY@EJ-E!B9>8):3(G(3(G#3#'02"-'"$C!XQY,,=!$C20"2(M7"$B+
M1PA,B>9(P>(>2,'H`D@)T$R)RDC![AN)P4@QRDPAPDPQRD@!ZDR)Y4C!Y05(
M"?5(`=5,B<)(P>H"08GM2`G32(M4)!!(,=A!B=M,(>!)C901F7F"6D@QR$J-
MC#&9>8):2(TT$$B)ZDC![1M(N.#___\?````2,'B!8/E'T@APD@)ZD@!\DR)
MYDG![`)(P>8>B=5,">9(,?-!B?1,(>M,,=M(`<M(B=%(P>H;2,'A!8/B'T@A
MP4@)RDR)Z4G![0)(P>$>2`':3`GI3(ML)"")TT@QSD&)SD@A[D^-G"N9>8):
M3#'F3`'>28G32,'J&TG!XP6#XA])(<-)"=-(BU0D*$D!\TB)[DC![0)(P>8>
M28V4%)EY@EI%B=U(">Y(,?&)]4@AV4PQ\4@!RDR)V4C!X05((<%)P>L;08/C
M'TP)V4R+7"0P2`'12(G:2,'K`DC!XAY/C9P>F7F"6D&)S$@)VD@QUHG33"'N
M2#'N20'S2(G.2,'I&TC!Y@6#X1]((<9("<Y(BTPD.$P!WDV)ZTG![0))P>,>
M2(V,#9EY@EI!B?9-">M,,=I%B=U,(>)(,=I(`=%(B?)(P>X;2,'B!8/F'T@A
MPD@)\DB+="1`2`'*3(GA2,'A'DG![`)(C;0SF7F"6HG53`GA23'+08G,32'S
M33'K3`'>28G32,'J&TG!XP6#XA])(<-)"=-(BU0D2$D!\TR)]DG![@)(P>8>
M28V4%9EY@EI$B=M,"?9(,?%!B?9((>E,,>%(`<I,B=E)P>L;2,'A!4&#XQ](
M(<%,"=E,BUPD4$@!T4B)ZDC![0)(P>(>3XV<')EY@EI!B<U(">I(,=:)U4@A
MWDPQ]DD!\TB)SDC!Y@5(P>D;2"'&@^$?2`G.2(M,)%A,`=Y)B=M(P>L"2<'C
M'DF-C`Z9>8):08GT20G;3#':1(G;3"'J2#'J2`'12(GR2,'N&TC!X@6#YA](
M(<)("?)(BW0D8$@!RDR)Z4G![0)(P>$>2(VT-9EY@EI!B=9,">E),<M!B<U-
M(>-),=M,`=Y)B=-(P>H;2<'C!8/B'TDAPTD)TTB+5"1H20'S3(GF2,'F'DG!
M[`)(C903F7F"6D2)W4P)YD@Q\4&)]$PA\4PQZ4@!RDR)V4G!ZQM(P>$%08/C
M'T@AP4P)V4R+7"1P2`'13(GR2<'N`DC!XAY/C9P=F7F"6HG+3`GR2#'608G6
M2"'N3#'F20'S2(G.2,'I&TC!Y@6#X1]((<9("<Y(BTPD>$P!WDF)ZTC![0))
MP>,>28V,#)EY@EI!B?5)">M,,=I$B=U((=I,,?)(`=%(B?)(P>X;2,'B!8/F
M'T@APD@)\DB+M"2`````2`'*2(G92,'K`DC!X1Y)C;0VF7F"6D&)U$@)V4DQ
MRXG+32'K23'K3`'>28G32,'J&TG!XP6#XA])(<-)"=-(BY0DB````$D!\TR)
M[DG![0)(P>8>2(V4%9EY@EI%B=Y,">Y(,?%!B?5,(>%(,=E(`<I,B=E)P>L;
M2,'A!4&#XQ]((<%,"=E(`=%,B>))P>P"2,'B'HG-3`GB3(ND))````!(,=9!
MB=-,(?9*C9PCF7F"6DPQ[D@!WDB)RTC!Z1M(P>,%@^$?2"'#2`G93(GS2<'N
M`DC!XQZ)R4P)\T@!SDB+C"28````2#':08GT2"'J28V,#9EY@EI-B>5,,=I)
MP>T;2`'*3(GA2,'A!4P)Z8G)2`'*2(GI2,'M`DC!X1Y!B=5(">E(B=V)VT@Q
MS3'N2(NL)*````!-C9PKH>O9;DR)[4D!\TR)[DC!Y@5(P>T;2`.<)*@```!(
M">Z)]DP!WDV)XTG![`))P>,>B?5-">-)B<R)R4@#C"2P````33'<1#'B3(VD
M$Z'KV6Y(B>I(B>M(P>L;2,'B!4@)VHG228T<%$R)ZDG![0)(P>(>08G<3`GJ
M38G=18G;3`.<)+@```!),=5$,>Y-B>5(C;0QH>O9;DR)X4G![1M(P>$%3`GI
MB<E(`?%(B>Y(P>T"2,'F'D&)S4@)[DB)U8G22#'U,>M,B>U)C9P;H>O9;DV)
MZTC![1M)P>,%20GK18G;20';3(GC2,'C'DG![`)$B=U(`Y0DP````$P)XTF)
M](GV2`.T),@```!),=Q$,>%)B>Q(C8P*H>O9;DB)ZDG![!M(P>(%3`GBB=)(
M`<I,B>E)P>T"2,'A'D&)U$P)Z4F)W8G;2`.<)-````!),<U%,>M-B>5.C9P>
MH>O9;DR)YDG![1M(P>8%3`GNB?9,`=Y)B>M(P>T"2<'C'D&)]4D)ZTB)S8G)
M3#'=,>I(C:P3H>O9;DR)ZDR)ZTC!ZQM(P>(%2`G:B=)(C5P5`$R)XDG![`)(
MP>(>B=U,">)-B=Q(`XPDV````$6)VTDQU$P#G"3@````1#'F28GL2(VT,:'K
MV6Y(B>E)P>P;2,'A!4P)X8G)2`'Q3(GN2<'M`DC!YAY!B<Q,">Y)B=6)TD@#
ME"3H````23'U1#'K38GE28V<&Z'KV6Y-B>-)P>T;2<'C!4T)ZT6)VTD!VTB)
MZTC![0)(P>,>18G=2`GK2(GUB?9(`[0D\````$@QW3'I3(GM2(V,"J'KV6Y,
MB>I(P>T;2,'B!4@)ZHG22`'*3(GA2<'L`DC!X1Z)U4P)X4F)W(G;23',13'C
M28GL2`.<)/@```!.C9P>H>O9;DB)[DG![!M(P>8%3`GFB?9,`=Y-B>M)P>T"
M2<'C'D&)]$T)ZTF)S8G)2`.,)``!``!-,=U$,>I,C:P3H>O9;DR)XDR)XTC!
MZQM(P>(%2`G:B=))C5P5`$B)ZDC![0)(P>(>08G=2`GJ3(G=18G;3`.<)`@!
M``!(,=4Q[DR)[4B-M#&AZ]EN3(GI2,'M&TC!X05(">F)R4@!\4R)YDG![`)(
MP>8>B<U,">9)B=2)TDDQ]$0QXTF)[$F-G!NAZ]EN28GK2<'L&TG!XP5-">-(
M`Y0D$`$``$6)VTD!VTR)ZTG![0)(P>,>18G<3`GK28GUB?9(`[0D&`$``$DQ
MW40QZ4V)Y4B-C`JAZ]EN3(GB2<'M&TC!X@5,">J)TD@!RDB)Z4C![0)(P>$>
M08G52`GI2(G=B=M(`YPD(`$``$@QS4$QZTR)[4Z-G!ZAZ]EN3(GN2,'M&TC!
MY@5(">Z)]DP!WDV)XTG![`))P>,>B?5-">-)B<R)R4TQW$0QXDR-I!.AZ]EN
M2(GJ2(GK2,'K&TC!X@5("=J)TDF-'!1,B>I(P>(>2<'M`D&)W$@#C"0H`0``
M3`GJ38G=18G;3`.<)#`!``!),=5$,>Y-B>5(C;0QH>O9;DR)X4G![1M(P>$%
M3`GIB<E(`?%(B>Y(P>T"2,'F'D&)ST@)[DB)U4V)_8G22#'U2<'E!4@#E"0X
M`0``,>M)C9P;H>O9;DV)^TG!ZQM-">M.C2P;3(GC2<'L`DF)\TC!XQY$B>V)
M]DP)XTDQVT&)WD0QV4V)ZTG![1M)P>,%2(V4"J'KV6Y!@^4?3(GY2,'A'DDA
MPTG![P)-">M)B=U)`=-,"?FZW+P;CT&)STD)S46)W$PA^TDA[4D)W4B+G"1`
M`0``2`'32`'>20'U3(G>2<'K&TC!Y@5!@^,?2"'&3`G>3`'N28GM2,'M`DG!
MY1Z)\TD)[4P)Z4V)ZT2)[4TA^TPAX4P)V4R+G"1(`0``20'330'S38GF2<'L
M`DD!RTB)\4C![AM(P>$%@^8?2<'F'D@AP4@)\4R)[DP!V4T)YD6)]$P)]D&)
MRT@AWDTAY4D)]4B+M"10`0``2`'63`'^28G?2,'K`DD!]4B)SDG!YQY(P>8%
M2,'I&TD)WT@AQH/A'TT)_D2)^T@)SDR)^4TAWDPAX4P![DD)SDB+C"18`0``
M08GU2`'12`'I20'.2(GQ2,'N&TC!X06#YA]((<%("?%,B?Y,`?%-B=Y)P>L"
M2<'F'HG-30G>18GS3`GV3"'N32'?20GW2(NT)&`!``!(`=9,`>9)`?=(B<Y(
MP>D;2,'F!8/A'T@AQD@)SDP!_DV)[TG![0))P><>08GT30GO30G^3(GY18G]
M3"'922'N20G.2(N,)&@!``!(`=%(`=E)`<Y(B?%(P>X;2,'A!8/F'T@AP4@)
M\4R)_DP!\4F)[DC![0))P>8>B<M)">Y$B?5,"?9,(>9)(>])"?=(B[0D<`$`
M`$@!UDP!WDD!]TB)SDC!Z1M(P>8%@^$?2"'&2`G.3`'^38GG2<'L`DG!YQY!
MB?--">=-"?Y,B?E%B?Q((>E)(=Y)"<Y(BXPD>`$``$@!T4P!Z4F)W4C!ZP))
M`<Y(B?%(P>X;2,'A!8/F'TG!Y1Y((<%("?%,B?Y,`?%)"=U$B>M,">Y!B<Y,
M(=Y)(=])"?=(B[0D@`$``$@!UD@![DD!]TB)SDC!Z1M(P>8%@^$?2"'&2`G.
M3`'^38G?2<'K`DG!YQZ)]4T)WTT)_4R)^46)^T@AV4TA]4D)S4B+C"2(`0``
M2`'13`'A20'-2(GQ2,'N&TC!X06#YA]((<%("?%,B?Y,`>E-B?5)P>X"2<'E
M'D&)S$T)]46)[DP)[D@A[DTA]TD)]TB+M"20`0``2`'62`'>20'W2(G.2,'I
M&TC!Y@6#X1]((<9("<Y,`?Y)B>](P>T"2<'G'HGS20GO30G]3(GY1(G]3"'Q
M32'E20G-2(N,))@!``!(`=%,`=E)`<U(B?%(P>X;2,'A!8/F'T@AP4@)\4R)
M_DP!Z4V)Y4G![`))P>4>08G+30GE18GL3`GN2"'>32'G20GW2(NT)*`!``!(
M`=9,`?9)`?=(B<Y(P>D;2,'F!8/A'T@AQD@)SDP!_DF)WTC!ZP))P><>08GV
M20G?30G]3(GY1(G[3"'A32'=20G-2(N,)*@!``!(`=%(`>E,B=U)P>L"20'-
M2(GQ2,'N&TC!X06#YA](P>4>2"'!2`GQ3(G^3`'I3`G=08GK2`GN08G-3"'V
M32'?20GW2(NT)+`!``!(`=9,`>9)`?=(B<Y(P>D;2,'F!8/A'T@AQD@)SDP!
M_DV)]TG![@))P><>08GT30GW3`G]3(GY18G^3"'93"'M2`G-2(N,)+@!``!(
M`=%(`=E,B>M)P>T"2`'-2(GQ2,'N&TC!X06#YA](P>,>2"'!2`GQ3(G^2`'I
M3`GK08G=2`G>B<U,(>9-(>])"?=(B[0DP`$``$@!UDP!WDV)XTG![`))`?=(
MB<Y)P>,>2,'F!4C!Z1M-">-((<:#X1],"=M%B=Q("<Y,B=E((>M,(>E,`?Y(
M"<M(BXPDR`$``$&)]T@!T4P!\4V)WD@!RTB)\4C![AM(P>$%@^8?2"'!2`GQ
M2`'92(GK2,'M`DC!XQZ)SD@)W8GK20GN32'^22';30GS3(NT)-`!``!)`=9(
M`Y0DV`$``$T!]4P!XDT!W4F)RTC!Z1M)P>,%@^$?22'#3`G9B<E,`>E-B?U)
MP>\"2<'E'D&)RTT)[TV)W$P)_4V)_DG![!M%B?U)(=Y((?5,"?5,B[0DX`$`
M`$@!U4R)VDC!X@5,">*)TD@!U4B)\DC![@)(P>(>08GL2`G6NM;!8LI),?=$
M,?E)`=9,`?--B>9(`<M,B>%)P>X;2,'A!4P)\8G)2`'+3(G92<'K`DC!X1Y!
MB=Y)"<M(B?&)]DPQV3'-2(N,).@!``!(`=%,`>E-B?5(`<U,B?%)P>T;2,'A
M!4P)Z8G)2`'-3(GA2<'L`DC!X1Y!B>U)"<Q(BXPD\`$``$@!T4@!\4R)WD6)
MVTPQYC'>3(GK2`'.3(GI2,'K&TC!X05("=F)R4@!SDR)\4C!X1Y)P>X"B?-)
M"<Y(BXPD^`$``$@!T4P!V4V)XT6)Y$TQ\T0QW4F)VT@!S4B)V4G!ZQM(P>$%
M3`G93(N<)``"``")R4@!S4R)Z4D!TTG![0)(P>$>30'C38GT08GO3`GI18GV
M23',1#'F38G\20'S3(G^2<'L&TC!Y@5,">9!B?1(B=Y(P>L"2,'F'DT!W$F)
MRXG)2`GS2(NT)`@"``!%B>5),=M(`=9$,=U-B>M,`?9(`?5,B>Y(P>8%2<'K
M&TP)WDV)^TG![P*)]DG!XQY(`?5(B[0D$`(``$T)^T&)[D@!UD@!\4B)WHG;
M3#'>03'T3(GV20',3(GQ2,'N&TC!X05("?&)R4D!S$R)Z4G![0)(P>$>18GG
M20G-2(N,)!@"``!,B?Y(P>X;2`'12`'93(G;18G;3#'K,>M(`<M,B?E(P>$%
M2`GQ3(GV2<'N`HG)2,'F'D@!RTB+C"0@`@``3`GVB=U(`=%,`=E-B>M%B>U)
M,?-%,=Q)B>M)`<Q(B>E)P>L;2,'A!4P)V4F)\XGVB<E)`<Q,B?E)P>\"2,'A
M'D6)YDD)STB+C"0H`@``33'[2`'11#';38GS3`'I2<'K&T@!RTR)\4C!X05,
M"=E,BYPD,`(``(G)2`'+2(GI2,'M`DD!TTC!X1Y!B=U,`=Y(">E,B?U-B>M%
MB?](,<U)P>L;1#'E2`'U3(GN2,'F!4P)WDF)RXG)B?9(`?5,B?9(P>8>2<'N
M`D&)[$D)]DB+M"0X`@``33'S2`'61#';38GC3`'^2<'K&T@!\TR)YDC!Y@5,
M"=Y-B>M)P>T"B?9)P>,>2`'S2(NT)$`"``!-">M!B=](`=9(`?%,B?9%B?9,
M,=XQ]4R)_D@!S4R)^4C![AM(P>$%2`GQ3(G>18G;B<E(`<U,B>%)P>P"2,'A
M'D&)[4D)S$B+C"1(`@``3#'F2`'1,?-,B>Y,`?%(`<M,B>E(P>$%2,'N&T@)
M\4R)_DG![P*)R4C!YAY(`<M(BXPD4`(``$P)_D&)WD@!T4P!V4V)XT6)Y$DQ
M\T$QZTR)]4D!RTR)\4C![1M(P>$%2`GIB<E)`<M,B>E)P>T"2,'A'D2)W4D)
MS4B+C"18`@``2`'13`'A28GTB?9-,>Q$,>-)B>Q(`<M(B>E)P>P;2,'A!4P)
MX8G)2`'+3(GQ2<'N`DC!X1Y!B=Q,"?%,B[0D8`(``$D!UDP!]DV)[D6)[4DQ
MSD4Q\TV)YDP!WDV)XTG![AM)P>,%30GS28GN2,'M`DG!YAY%B=M,"?5,B[0D
M:`(``$P!WD&)\TD!UDT!]4F)SHG)23'N1#'S38G>3`'K38G=2<'N&TG!Y05-
M"?5-B>9)P>P"2<'F'D6)[4T)]$R+M"1P`@``3`'K08G=20'63`'Q28GNB>U-
M,>9$,?9-B>Y(`<Y,B>E)P>X;2,'A!4P)\4@!\4R)WDC!YAY)P>L"2`.4)'@"
M``!)"?-,B>9,`<)$`V<@3#'>2`'J10':3(EG(#'S2(G.3(E7&$C!Y@5(`=I(
M(?!(B<X#3PA(P>X;2(E/"(/F'T@)\`'02(D'3(GH2<'M`DC!X!Y)"<5%`>E,
MB4\02(N$)(@"``!D2#,$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^@<Y?__
M9F8N#Q^$``````"005=!5D%505154TB#[`A(A?\/A+$```!,BS6RC@``387V
M#X2A````#[8'28G_2(GUA,!T!#P]=5A%,>U-BR9-A>1T,TUC[4R)\P\?@```
M``!,B>I,B?Y,B>?HTN+__X7`=0=#@#PL/71'3(MC"$B#PPA-A>1UVDB#Q`A,
MB>!;74%<05U!7D%?PP\?A```````28G]00^V10%)@\4!A,!T!#P]=>]%*?WK
MD@\?@`````!,*?-/C60L`4C!^P.)70#KM0\?@`````!%,>3KJ0\?`%532(G[
M2(/L&&1(BP0E*````$B)1"0(,<!(C6PD!&:0,<!(B>Y(B=_H`____TB%P'0V
M2&-4)`1(BP7"C0``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U
M\.N^9@\?1```2(M$)`AD2#,$)2@```!U!TB#Q!A;7</HO./__V9F+@\?A```
M````D$%7059!54%454B)]5-(B?M(@^PH9$B+!"4H````2(E$)!@QP#'`@#X]
M#Y3`2`'%2(GOZ&GB__](C70D%$B)WTF)Q#'`Z%?^__](A<`/A`X!``!(B<=)
MB<7H0^+__TPYX`^#V@```$QC="042<'F`P^V`X3`#X2N`0``/#T/A*8!``!(
MB=@/'P`/ME`!2(/``832=`6`^CUU[T@IV$B82HU\(`),`S7&C```Z#'A__])
MB09(A<`/A(8!``!(BP6NC```2&-4)!1(C4L!2(L4T`^V`X@"/#UT'83`=0CK
M%V:0/#UT$0^V`4B#P@%(@\$!B`*$P'7KQ@(],<!F#Q]$```/MDP%`(A,`@%(
M@\`!A,EU[S'`2(M<)!AD2#,<)2@````/A14!``!(@\0H6UU!7$%=05Y!7\-F
M+@\?A```````,<!F#Q]$```/ME0%`$&(5`4`2(/``832=>[KM0\?0`!,BST)
MC```28,_``^$O@```$R)^$4Q[68/'X0``````$B#P`A$B>I!@\4!2(,X`'7O
MC7(#2&/V2,'F`XL%+YP``(7`=5O'!2&<```!````2(GWZ"G@__](A<`/A($`
M``!-8\5,B?Y(B<=.C33%`````$R)1"0(3(GRZ&+A__],BT0D"$B)!8:+``!(
MB<%*QT3!"`````!$B6PD%.EO_O__3(G_Z%CB__](B05ABP``2(G!2(7`="I-
M8\5.C33%`````.O)#Q]``#'`Z6_^__^^$````$4Q[>E?____Z&_A__^#R/_I
MRO[__P\?@`````!!5D%505154TB![*````!D2(L$)2@```!(B80DF````#'`
M2(7_=`B`/P!(B?UU,4B+A"28````9$@S!"4H````#X41`0``2('$H````%M=
M05Q!74%>PV8N#Q^$``````#H^]___TF)Q$B%P'3"2(GC3(GGZ-CA__](A<`/
MA*<```!F@W@3+DR-<!-TY&:!>!,N+@^$J````$B)[^BPW___3(GW28G%Z*7?
M__]!C7P%`DAC_^C8WO__38GQ28GHO@$```!)B<5(B<<QP$C'PO____](C0T.
M*@``Z!+A__^_`0```$B)VDR)[NC"X/__3(GO@_C_=!"+1"08)0#P```]`$``
M`'1*Z,7>__],B>_H+=___TR)Y^@UX?__2(7`#X5=____#Q]``$R)Y^BPX/__
M2(GOZ*C>___I\O[__P\?`$&`?@(`#X0E____Z4C____HJ_[__^NTZ`3@__\/
M'T``54B)_DB)_;\!````2('LH````&1(BP0E*````$B)A"28````,<!(B>+H
M@M___X7`=3:+5"08@>(`\```@?H`0```=`B!^@"@``!U'KX"````2(GOZ$?@
M__^%P`^4P`^VP.L'#Q]$```QP$B+C"28````9$@S#"4H````=0E(@<2@````
M7</H==___P\?1```05=!5D%505152('L`!```$B##"0`2(/L$+K_#P``9$B+
M!"4H````2(F$)`@0```QP$F)Y4B)_4F)]$B-/;PH``!,B>[HE][__X7`?GN-
M4/]$BSVYB```3&/R0H`\-`!U7X72=&I,B?*^+P```$R)[^C+W/__2(7`=%5$
MB?_H7MS__TR)\4R)ZDB)[DB)Q^@]WO__2(N$)`@0``!D2#,$)2@```!U04B!
MQ!`0``!=05Q!74%>05_#9@\?A```````3&/PZZ`/'P!$BSU!B```1(G_Z`G<
M__],B>)(B>Y(B<?H&]W__^NLZ(3>__\/'T``\P\>^DB#[`B+/1*(``#HW=O_
M_TB+%=:'``!(@\0(2(T-^V8``$B)QTB-->TG``#I#-___V9F+@\?A```````
MD/,/'OI(@^P(BSW2AP``Z)W;__](B<?HI?___XL]OX<``.B*V___3(T%1"D`
M`$4QR4B-%0D3``!(B<=,B<%(C36T)P``2(/$".D3W?__#Q\`\P\>^D%455-(
M@>P`$```2(,,)`!(@>P`$```2(,,)`!(@^P@9$B+!"4H````2(F$)!@@```Q
MP$B)Y4R-I"00$```Z%G<__],C0TZ)P``N@$0``!(B>]!B<!(C0U=)P``O@$`
M```QP.@4WO__N@`0``!,B>9(B>_HY-S__T4QP(7`>"Z->`%(B<-(8__HC]O_
M_TF)P$B%P'082&/;3(GF2(G'2(G:Z";>___&!!@`28G`2(N$)!@@``!D2#,$
M)2@```!U#TB!Q"`@``!,B<!;74%<P^@8W?__#Q^$``````#S#Q[ZZ1?___\/
M'X``````\P\>^D%7059!54%455-(@>P`$```2(,,)`!(@>RX````9$B+!"4H
M````2(F$)*@0```QP$F)_$F)]DB-/9@F``!(C70D#.BE]___OB\```!,B>=(
MB<7H1=S__TB%P'1`3(GF2(T]>"8``#'`Z-_X__],B>!(BXPDJ!```&1(,PPE
M*`````^%<@$``$B!Q+@0``!;74%<05U!7D%?PP\?`$R)Y^A(V___2(TU0"8`
M`$R)]T&)Q>AFW/__2(G#2(7`=)Z`.P!,C36Y)0``#X35````9@\?1```2(7M
M=!-(B=Y(B>_H*-S__X7`#X24````2(G?Z/C:__^)PDB8@'P#_R]U%@\?1```
M@^H!2&/"@'P#_R_&!`,`=.]!C405`3W_#P``#X\W____28G8N@`0``"^`0``
M`#'`3(V\)*````!(@^P(2(T-G"8``$%43(T-G24``$R)_^@TW/__2(U4)"!,
MB?Z_`0```.CBV___6EF%P'40BT0D*"4`\```/0"```!T3$B--60E```Q_^B.
MV___2(G#2(7`#X3"_O__@#L`#X4Q____2(7M=`:`?0`N=`Y,B?.Z`0```.E:
M____D(!]`0!TONOJ#Q^$``````"^`0```$R)_^C#V___A<!UHTR)_DB-/?<D
M``#H8/?__TR)_^CHVO__Z7?^___H_MK__V9F+@\?A```````#Q\`\P\>^@^V
M!TF)^(3`=!-FD$B#QP$\+P^V!TP/1,>$P'7O3(G`PV9F+@\?A```````\P\>
M^DB%_P^$PP```%6`/P!(B?T/A)X```#HD=G__TB-5`7_2#G5<A#IEP```&:0
M2(/J`4@YU70E@#HO=/)(.=4/@WX```!(@^H!2#G5=`Z`.B]T($B#Z@%(.=5U
M\H`Z+W152(T]1R0``%WI,-K__X`Z+W4)2(/J`4@YU7+R2"GJ,<!(C4H"2('Y
M`!```'<?2(/"`;D`$```2(GN2(T]/80``.BXU___2(T%,80``%W##Q^`````
M`$B-/88C``!=Z=O9__](.=5UJ^N2#Q]``$B-/6XC``#IQ-G__P\?0`#S#Q[Z
M53'22(T]Q2,``$B#[$!F#V\%=F(``&1(BP0E*````$B)1"0X,<!FB50D,$B-
M;"0,#RE$)!!F#V\%7V(```\I1"0@Z%7U__\QP$B-/8@C``#H1_7__S'`2(T]
M@B,``.@Y]?__,<!(C3U](P``Z"OU__\QP$B-/78C``#H'?7__S'`2(T]>",`
M`.@/]?__,<!(C3T?(P``Z`'U__\QP$B-/6@C``#H\_3__S'`2(T]9",``.CE
M]/__,<!(C3U@(P``Z-?T__\QP$B-/?`B``#HR?3__S'`2(GN2(T]2R,``.CH
M\___2(7`=!%(B<9(C3TC(P``,<#H,O7__TB)[DB-/3<C```QP.C!\___2(G&
M2(7`=`Y(C3TS(P``,<#H"_7__TB)[DB-/2TC```QP.B:\___2(G&2(7`=$)(
MC3UT(@``,<#HY/3__S'`2(TU,R,``$B-/9@B``#HS_3__TB+1"0X9$@S!"4H
M````=6!(@\1`7<-F#Q^$``````!(B>Y(C3WB(@``,<#H/_/__TB)QDB%P'07
M2(T]<"(``#'`Z(GT___KHP\?@`````!(N%!!4E]#3$5!2#E$)"%UBV:!?"0I
M3CUU@DB-="0KZ\CH"MC__V8N#Q^$``````#S#Q[Z2(/L&&1(BP0E*````$B)
M1"0(,<"+!7*!``"#^/]T'4B+?"0(9$@S/"4H````=41(@\08PP\?A```````
M2(UT)`1(C3WD(0``,<#HG?+__TB)PC'`2(72=!(/MA*`^C`/E<$QP(32#Y7`
M(<B)!1N!``#KK.B$U___#Q]``/,/'OI(@^P(Z*/7__^)Q^@LUO__2(7`=`-(
MBP!(@\0(PV9F+@\?A```````#Q]``/,/'OI!5%5(B?U(C3WI(0``4TB#[!!D
M2(L$)2@```!(B40D"#'`2(UT)`3H$/+__TB)[DB%P'0(@#@`2(G#=3!(C3VS
M(0``,<#H4O/__TB+1"0(9$@S!"4H````#X5_````2(/$$%M=05S##Q]$``!(
MB<?H*-;__TB%P'712(GOZ+O5__](B=])B<3HL-7__TF-?`0"Z.;4__](@^P(
M28GHO@$```!32,?"_____TB)QTF)Q$R-#80@``!(C0UU(0``,<#H%]?__TR)
MYDB-/2<A```QP.C&\O__6%KI;?___^AJUO__9BX/'X0``````/,/'OI!5T%6
M055!5%533(V<)`"`__](@>P`$```2(,,)`!,.=QU[TB![)@!``!D2(L$)2@`
M``!(B80DB($``#'`2(T%WB```$R-;"0L28G_2(E$)#!(C06)'P``3(GN2(T]
MTQ\``$B)1"0X2(T%6"```$B)1"1X2(T%K2```$B)A"2`````2(T%6B```$B)
MA"2(````2(T%ER```$B)A"20````2(T%C"```$B)1"18,<!(QT0D0`````!(
MQX0DF`````````!(QT0D8`````#H>_#__TB%P'0,@#@`2(G%#X7Z!```,<#H
M\_W__TB)Q4B%P`^$1P0``$B)[^A/U/__2(U\``'HA=/__T0/MD4`2(G#183`
M=#M)B=Y,C24>(```9@\?1```3(GW3(GA2,?"_____S'`O@$```!(@\4!28/&
M`NBGU?__1`^V10!%A,!UU4R-9"1P2(T]<A\``.L9#Q^``````$F+?"0(28/$
M"$B%_P^$E@$``$R)[C'`Z,SO__](B<5(A<!TW(`X`'372(G'Z,?T__^%P'3+
M2(GOZ)O4__])B<9(A<`/A%\!```/'X``````3(GQBQ%(@\$$C8+__O[^]](A
MT"6`@("`=.F)PL'J$*F`@```#T3"2(U1`D@/1,J)P@#"2(G:2(/9`TPI\8LR
M2(/"!(V&__[^_O?6(?`E@("`@'3IB<;![A"I@(````]$QDB-<@)(#T36B<9`
M`,9(@]H#2"G:1(VD$00$``!-8^1,B>?H4-+__U-,C0T)'@``38GP2(G%2(T%
M^1X``+X!````2,?"_____U!(C0W<'@``2(GO,<#H?=3__[[``0``2(GOZ.#4
M__]!6$%9@_C_=1+HHM/__T2+"$&#^1$/A1D#``!,C;0DH````$B)[K\!````
M3(GRZ%W3__^)PX7`#X2S````28L/2(L]>7T``$F)Z#'`2(T5+1\``+X!````
M13'DZ&#1__](BX0DB($``&1(,P0E*`````^%7`@``$B!Q)B!``!,B>!;74%<
M05U!7D%?PP\?0`!(BVPD,$4QY.L39@\?1```26/$2(MLQ#!(A>UT.X!]``!T
M-4B)[T&#Q`'H(?/__X7`=-U(B>_H]=+__TF)QDB%P`^%8?[__TECQ$B+;,0P
M2(7M=<D/'T``13'VZ4C^__^+A"2X````)0#P```]`$````^%-O___XN$)+P`
M``")!"3H^M+__SD$)`^%'O___XN$)+@````E_P$``#W``0``#X4'____3(GG
MZ-+0__](C3U0'0``3(GN28G$,<#H?NW__TB)QTB%P`^$(@(``.A=TO__28L_
M2(G&Z'+U__])B<5(A<`/A`8"``!,B>_H3M'__X/X`WY!2&/0N04```!(C3T]
M'0``28UT%?SSI@^7PH#:`(32=2&#^`0/A-`%``"#Z`1(F$&`?`7_+P^$OP4`
M``\?@``````QP.@1^O__A<!U%3'V3(GOZ$/1__]!B<>%P`^%H`$``$B--9D<
M``!(C3T:'```,<#H,^[__TR-+0T=``!,C37&&P``Z(#0__]!54F)Z+X!````
M4$C'PO____],B><QP$R-#:,;``!(C0VW'```Z#;2__]86NM#9I#H:]'__X,X
M$75)Z$'0__^#PP%(@^P(38GQ055)B>A(C0V5'```3(GG4TC'PO____^^`0``
M`%`QP.CST?__2(/$(+[``0``3(GGZ%+2__^#^/]TK4B)[^@ET/__3(GF2(T]
M%!L``#'`Z(3M__],B>?HW/G__^FG_?__#Q^``````$B-/=,;```QV^L2#Q]$
M``!(8\-(BWS$4$B%_W0X3(GN,<"#PP'HYNO__TB%P'3A@#@`=-Q(B<?HQ-#_
M_TB)Q4B%P`^%<?O__TACPTB+?,102(7_=<B_#0```$B-+7X;``#HZL[__T&X
M4P```$B)P^ED^___28L/2(L]@GH``$F)Z#'`2(T5]AL``+X!````13'DZ&G.
M___I!/W__P\?0`!(B<?H*/G__TB)[^A0T/__28G$Z>C\__\/'X0``````$V+
M+^GR_?__N@(```!(Q\;N____B<?HM=#__TB-A"2``0``N@8```!$B?](B<9(
MB00DZ#G.__^`O"2``0```'4.@+PD@0$``$,/A(,$```QTC'V1(G_Z'70__^X
MB:O-[TC'A"2@`````2-%9TB)A"2H````2"V+SA)72(F$)+````!(!?($&"M(
MB80DP````$B-A"38````2,>$)+@```!V5#(02,>$),@`````````2,>$)-``
M````````QX0D&`$```````!(B40D&`\?0`!(BS0DN@"```!$B?_HC\W__TB)
MP4&)P(7`#XY=`0``2(N\),@```!(BY0DT````$ACP4B+'"2--,](.?Y(B;0D
MR````$B#T@!(P>@=2`'02&.4)!@!``!(B80DT````(72#X6I````08/X/P^.
M`0,``$&-0,")1"04P>@&08G%B40D"$F#Q0%)P>4&20'=9I#S#V\+\P]O4Q!,
MB?=(@\-`\P]O6^#S#V]C\`\1C"38````#Q&4).@````/$9PD^`````\1I"0(
M`0``Z.'2__],.>MUO(M$)`A$BT0D%,'@!D$IP$B+?"0826/0N4@```!,B>Y$
MB40D".@SS?__1(M$)`A$B80D&`$``.GQ_O__D$&X0````$B+1"082(LT)$B)
M3"0(02G01#G!2(T\$$0/3L%)8]A(B=KH,\___XN$)!@!``!(BTPD"`'8@_A`
MB80D&`$```^%I?[__T&)R$R)]T$IV$@#'"1$B40D".@^TO__1(M$)`CIZ_[_
M_T2)_^B\R___2(N$),@```"+G"3(````1(NL)-````!(P>@##\N#X#]!#\V-
M2`%(F,:$!-@```"`@_DX#XZ]`0``ND````!(8_%(`W0D&"G*=`\QP(G!@\`!
MQ@0.`#G0<O-,B??HR]'__V8/[\!(QX0D"`$````````/$80DV`````\1A"3H
M````#Q&$)/@```!,B?=$B:PD$`$``$R-O"0Q`0``3(VT)'@!``")G"04`0``
M3(TM.A@``.AUT?__2(N$)*`````/MY0DH````$F)P$C!Z!"(A"0Q`0``9L'"
M"$G!Z!B+A"2H````9HF4)#(!```/R(F$)#0!``"+A"2P````#\B)A"0X`0``
MBX0DN`````_(B80D/`$``(N$),`````/R(F$)$`!``!(C80D4`$``$B)!"1(
MB</K#F8/'T0``$4/M@=)@\<!2(G?10^VP$R)Z;X!````2,?"_____S'`2(/#
M`N@WS?__23G>==)(C07,%P``QH0D>`$```!0_W0D"$B-#807``!)B>A,B><Q
MP+X!````3(T-9!8``$C'PO_____H]\S__UE>Z1/[__]-BW\(387_#X0[^O__
M3(G_Z#O+__](@_@##X8I^O__28UT!_RY!0```$B-/2@7``#SI@^7P!P`A,!-
M#T3OZ0;Z__])B=WI:?W__[HX````2&/!,?](`T0D&"G*@_H(<S#VP@0/A=<`
M``"%T@^$;/[__\8``/;"`@^$8/[__S'_9HE\$/[I5/[__P\?@`````")T4C'
M``````!(QT0(^`````!(C4@(2(/A^$@IR`'0@^#X@_@(#X(B_O__@^#X,=*)
MUH/""$B)/#$YPG+SZ0O^__^`O"2"`0``00^%;_O__X"\)(,!``!##X5A^___
M@+PDA`$``$@/A5/[__^`O"2%`0``10^%1?O__[H"````2,?&QO___T2)_^BR
MR___2(L<)+HI````1(G_2(G>Z#[)__](C058%@``4%/IDO[__\<``````,=$
M$/P`````Z8K]___H",O__P\?A```````\P\>^D%7059!54%455-(@^P8BSV(
M=```9$B+!"4H````2(E$)`@QP$R-;"0$Z#[(__^+/6AT``!(B</H,,C__P^V
MD[@```!,B>Y(C3W#%```B)"Y````,<#HDN7__TB%P'0)@#@Q#X3T`@``,<#H
MK?#__XL])W0``.CRQ___N0L```"Z`0```$B--9P5``!(B<?HR<C__T2+-0)T
M``!(A<`/A,D```!(BT`0@SU^A````4R+8"@/CK0````QV^LR28MW$$B+!5V$
M``!(8]5(BSS0Z#G*__]!B<"+!5"$``!%A<`/A7P```"#PP(YPXGK?7-$B?>-
M:P'H<\?__S')2&/33(GF2(G'Z'/)__](A<!T1DR+.$2+-81S``!!BT<,)0`$
M(``]``0``'241(GWZ#S'__],B?ZY`@```#'22(G'Z,K*__]$BS53<P``2(G&
MZ6____\/'P"+!=*#``!$BS4[<P``C5#_.=H/A(`!``!$B??H^,;__[D#````
MN@$```!(C36G%```2(G'Z,_'__](B<-(A<!T-4B+0!"+/?UR``!(BRCHQ<;_
M_TB-%8`4``!(B<=(B>[HT\?__TB+0Q!(BRCV10Y`#X7.`0``BSW,<@``Z)?&
M__^Y`P```+H!````2(TU310``$B)Q^ANQ___2(G#2(7`=#U,B>Y(C3W>$@``
M,<#HY>/__TF)Q$B%P`^$60$``$B+0Q"+/7]R``!(BRCH1\;__TR)XDB)QTB)
M[NA9Q___BSUC<@``Z"[&__^Z`0```$B-->L3``!(B<?H.L;__XL]1'(``$B)
MQ>@,QO__2(T5XQ,``$B)[DB)Q^@:Q___BSTD<@``Z._%__],B>Y(C3U.$@``
MQH"Y`````#'`Z%?C__](B068@@``28G$2(7`#X2$````OL`!``!,B>?H1\G_
M_XU0`8/Z`78)@_@1#X7R````2(M$)`AD2#,$)2@````/A=D```!(@\086UU!
M7$%=05Y!7\,/'P"#^`$/CG?^__^[`0```&:01(GW@\,!Z&7%__],B>9(B<?H
M.L;__SD=%((``$2+-7UQ``!_V^E&_O__9@\?1```2(L]\8$``.AD\?__2(D%
M]8$``$F)Q$B%P`^%7?___TB-/:(3```QP.CCQ___#Q\`@'@!``^$"?W__^G]
M_/__D$B+!;&!``"+/2-Q``!,BR!(BT,02(LHZ.3$__],B>9(B>_H^>?__^F;
M_O__BSW^<```Z,G$__](B>Y(B<?H/L?__^D7_O__Z$3'__^)P4B+!6.!``!,
MB>)(C3U1$P``2(LP,<#H9\?__P\?@`````#S#Q[Z54B)_5-(@^P(Z$[L__\/
MMA!(B<.$TG06#Q]``$B#P`&`^B\/MA!(#T38A-)U[C'`Z.?N__](A>UT)(7`
M=""`?0``=!JY!````$B-/;H1``!(B=[SI@^7P!P`A,!T!TB#Q`A;7<-(@\0(
M2(GO6UWI2>7__V8/'X0``````/,/'OI!5TR-/<-K``!!5DF)UD%528GU051!
MB?Q52(TMM&L``%-,*?U(@^P(Z.^___](P?T#=!\QVP\?@`````!,B?),B>Y$
MB>=!_Q3?2(/#`4@YW77J2(/$"%M=05Q!74%>05_#9F8N#Q^$``````#S#Q[Z
MPV8N#Q^$``````"0\P\>^DB+#9UO``#I$,3___,/'OI(@^P(2(/$",,`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`N+@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),
M3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$
M14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)9
M7U!!5$@`55-%4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-10`E
M,#)X`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S
M)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P`%!!
M4CHZ4&%C:V5R.CI615)324].`#$N,#0W`"UE`"TM`````````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS
M869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO
M;BD*````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN
M:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@
M/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q
M>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z
M.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D
M<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@
M)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E
M;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,
M24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B
M)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M
M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M
M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N
M9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3
M,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G
M;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T
M85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N
M(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM
M>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`]
M(#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I
M>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@
M;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY
M("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A
M9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]
M("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*
M;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F
M<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S
M("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD
M;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F
M<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T
M.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES
M=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL
M;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M
M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L
M("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO
M/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F
M:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W
M-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*
M;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N
M86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM
M>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U
M;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R
M(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D
M;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE
M+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@
M>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN
M<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I
M;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN
M;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q
M=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?
M<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I
M*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN
M<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@
M=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E
M=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H
M:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM
M>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>
M+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G
M22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-
M)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U
M="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E
M)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE
M;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q
M("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A
M;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A
M8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@
M)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@
M9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB
M;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E
M<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^
M(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@
M/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0[
M"FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D
M:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T
M(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*
M0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O
M=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T
M85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S
M8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A
M9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E
M=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%
M3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@
M+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI
M?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T
M:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N
M9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E
M<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R
M:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F
M;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.
M0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY
M("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N
M86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D
M7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I
M*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@
M*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F
M(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q
M(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET
M=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN
M9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B
M+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D
M9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&
M24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II
M9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI
M>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E
M;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS
M<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD
M>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N
M86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?
M;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C
M='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M
M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG
M97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R
M<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD
M8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII
M9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H
M)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A
M8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]
M"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H
M+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U
M=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE
M;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M
M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT
M<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S
M=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB
M(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50
M871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M
M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ
M4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A
M=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q
M=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG
M<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U
M:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@
M<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@
M?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V
M86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@
M>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE
M=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C
M:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-
M4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N
M("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H
M(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@
M>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@
M*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@
M)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2![
M"B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.
M5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E
M<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I
M9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@
M)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H
M+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@
M)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E
M:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^
M(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB
M("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T[
M"FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA
M7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^
M861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!
M4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M
M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@
M7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?
M.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M
M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"([
M"F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R
M:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C
M;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I
M('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U
M<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^
M(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S
M="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M
M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D
M96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@
M)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L
M<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-0
M05=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%2
M1U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]]
M(#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.
M5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A
M<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!
M3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*
M<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R
M:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]
M"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?
M7T5.1%]?"@``````<&5R;'AS:2YC`````````%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@`1L#._0````=````T'#__R@!``"0=/__4`$``*!T
M__]H`0``4'C__T0&``!@>O__$`$``%![__^``0``()+__]`!``#PDO__'`(`
M`("3__](`@``T)7__Y0"```PE___V`(``,"7___\`@``L)C__T0#``#PF/__
M7`,``$"9__]T`P``()K__[`#```PFO__Q`,``$"<__\H!```<)S__SP$``!0
MG?__;`0``#"?__^0!```L)___ZP$``#@G___Q`0``-"@__\$!0``,*S__\0%
M```0L/__$`8``)"P__]P!@```+'__[@&```0L?__T`8````````4````````
M``%Z4@`!>!`!&PP'")`!```4````'````$AY__\O`````$0'$``````D````
M-````*!O___``P````X01@X82@\+=PB``#\:.BHS)"(`````%````%P````X
M<___$```````````````%````'0````P<___L`,`````````````3````(P`
M``#(>?__Q!8```!"#A"/`D8.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%
M`Y\6"@XX00XP00XH0@X@0@X80@X00@X(00L```!(````W````$B0___-````
M`$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH
M0@X@0@X80@X00@X(20L`*````"@!``#,D/__A`````!!#A"&`D$.&(,#1PXP
M`G,*#AA!#A!!#@A!"P!(````5`$``#"1__])`@```$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9$#CB#!T<.8`,7`0H..$$.,$$.*$(.($(.&$(.$$(."$L+
M0````*`!```TD___7`$```!"#A".`D(.&(T#0@X@C`1!#BB&!4$.,(,&1P[0
M`7X*#C!!#BA!#B!"#AA"#A!"#@A+"P`@````Y`$``%"4__^+`````$$.$(8"
M4@ZP`0)Q"@X000X(00M$````"`(``+R4___L`````$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9'#K`@20[`(`*4"@XP00XH0@X@0@X80@X00@X(2@L4````
M4`(``&25__\T`````$@.$%8."``4````:`(``(R5__]-`````$@.$`)`#@@X
M````@`(``,25___8`````$8.$(P"00X8A@-!#B"#!$<.H"!,#J!`20[`0`*G
M"@X@1`X800X00@X(00L0````O`(``&B6__\)`````````&````#0`@``9);_
M_P("````1@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1PZX($P.\"$"
M<0H..$$.,$$.*$(.($(.&$(.$$(."$0+`J0.^"%)#H`B8@[X(4$.\"$````0
M````-`,``!"8__\E`````````"P```!(`P``+)C__]P`````3@X0A@("70K&
M#@A%"P)`"@X(2`M("L8."$4+2PX(QB````!X`P``W)C__]8!````10X0A@)-
M#E`#8P$*#A!!#@A*"Q@```"<`P``F)K__WP`````2`X@;PH."$D+```4````
MN`,``/R:__\A`````$@.$%@."``\````T`,``!2;___F`````$8.$(P"00X8
MA@-+#B"#!$0.,`)0"@X@00X800X00@X(1@MN#CA)#D!T#CA!#C``O````!`$
M``#$F___6`L```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=(#`NX
M@`)1#0='#M"#`@,3`@[8@P)A#N"#`F`.V(,"0@[0@P(">@H..$0.,$$.*$(.
M($(.&$(.$$(."$4+`X(!#MB#`DD.X(,"8`[8@P)!#M"#`EH.V(,"10[@@P).
M#NB#`DT.\(,"2P[0@P(#S00.V(,"1`[@@P)H#MB#`D$.T(,"`S\!"@[8@P)!
M#N"#`D4+2````-`$``!DIO__V0,```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P=$#E`#T`(*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"S`````<!0``
M^*G__W<`````10X0A@)$#AB#`T0.(`)9"@X800X000X(00M$#AA$#A!!#@@H
M````4`4```1R__\,`@```$8.$(P"00X8A@-$#E`#IP$*#AA$#A!"#@A!"T0`
M``!\!0``&*K__V4`````1@X0CP))#AB.`T4.((T$10XHC`5$#C"&!D@..(,'
M1PY`;@XX00XP00XH0@X@0@X80@X00@X(`!0```#$!0``0*K__P4`````````
M`````!````#<!0``.*K__Q``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````D"H```````!0*@``
M``````$``````````0`````````!`````````+P!`````````0`````````+
M`@````````P``````````"`````````-`````````'!@````````&0``````
M``"PRP```````!L`````````"``````````:`````````+C+````````'```
M```````(`````````/7^_V\`````H`,````````%`````````,`-````````
M!@````````"0!`````````H`````````N@0````````+`````````!@`````
M````%0````````````````````,`````````T,T````````"`````````(@%
M````````%``````````'`````````!<`````````0!4````````'````````
M`,`3````````"`````````"``0````````D`````````&``````````>````
M``````@`````````^___;P`````!```(`````/[__V\`````0!,```````#_
M__]O``````(`````````\/__;P````!Z$@```````/G__V\`````!```````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````,#+````````
M`````````````````````#`@````````0"````````!0(````````&`@````
M````<"````````"`(````````)`@````````H"````````"P(````````,`@
M````````T"````````#@(````````/`@`````````"$````````0(0``````
M`"`A````````,"$```````!`(0```````%`A````````8"$```````!P(0``
M`````(`A````````D"$```````"@(0```````+`A````````P"$```````#0
M(0```````.`A````````\"$`````````(@```````!`B````````("(`````
M```P(@```````$`B````````4"(```````!@(@```````'`B````````@"(`
M``````"0(@```````*`B````````L"(```````#`(@```````-`B````````
MX"(```````#P(@`````````C````````$",````````@(P```````#`C````
M````0",```````!0(P```````&`C````````<",```````"`(P```````)`C
M````````H",```````"P(P```````,`C````````T",`````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T````````/____\`````Z'(```````!'
M0T,Z("A58G5N='4@.2XR+C$M.75B=6YT=3(I(#DN,BXQ(#(P,3DQ,#`X```N
M<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N9VYU
M+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR
M96QA+G!L=``N:6YI=``N<&QT+F=O=``N<&QT+G-E8P`N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"`````````!@#````````&`,`````
M```<`````````````````````0```````````````````!,````'`````@``
M```````X`P```````#@#````````(`````````````````````@`````````
M```````````F````!P````(`````````6`,```````!8`P```````"0`````
M```````````````$````````````````````.0````<````"`````````'P#
M````````?`,````````@````````````````````!```````````````````
M`$<```#V__]O`@````````"@`P```````*`#````````\``````````&````
M``````@```````````````````!1````"P````(`````````D`0```````"0
M!````````#`)````````!P````$````(`````````!@`````````60````,`
M```"`````````,`-````````P`T```````"Z!````````````````````0``
M`````````````````&$```#___]O`@````````!Z$@```````'H2````````
MQ``````````&``````````(``````````@````````!N````_O__;P(`````
M````0!,```````!`$P```````(``````````!P````(````(````````````
M````````?0````0````"`````````,`3````````P!,```````"``0``````
M``8`````````"``````````8`````````(<````$````0@````````!`%0``
M`````$`5````````B`4````````&````&`````@`````````&`````````"1
M`````0````8``````````"``````````(````````!L`````````````````
M```$````````````````````C`````$````&`````````"`@````````("``
M``````#``P``````````````````$``````````0`````````)<````!````
M!@````````#@(P```````.`C````````$````````````````````!``````
M````$`````````"@`````0````8`````````\",```````#P(P```````+`#
M```````````````````0`````````!``````````J0````$````&````````
M`*`G````````H"<```````#0.```````````````````$```````````````
M`````*\````!````!@````````!P8````````'!@````````#0``````````
M``````````0```````````````````"U`````0````(``````````'``````
M````<````````%`_```````````````````0````````````````````O0``
M``$````"`````````%"O````````4*\```````#T````````````````````
M!````````````````````,L````!`````@````````!(L````````$BP````
M````\`4```````````````````@```````````````````#5````#@````,`
M````````L,L```````"PNP````````@````````````````````(````````
M``@`````````X0````\````#`````````+C+````````N+L````````(````
M````````````````"``````````(`````````.T````&`````P````````#`
MRP```````,"[````````$`(````````'``````````@`````````$```````
M``";`````0````,`````````T,T```````#0O0```````#`"````````````
M```````(``````````@`````````]@````$````#``````````#0````````
M`,`````````@````````````````````"````````````````````/P````(
M`````P`````````@T````````"#`````````J!```````````````````"``
M```````````````````!`0```0```#`````````````````````@P```````
M`"P````````````````````!``````````$``````````0````,`````````
M````````````````3,`````````*`0```````````````````0``````````
'````````````
